"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const typescript_1 = __importDefault(require("typescript"));
/**
 * Log compiler diagnostics to stderr.
 * @internal
 */
function logDiagnostics(diagnostics, pretty = false) {
    if (!diagnostics.length)
        return;
    const formatHost = {
        getCanonicalFileName: (path) => path,
        getCurrentDirectory: typescript_1.default.sys.getCurrentDirectory,
        getNewLine: () => typescript_1.default.sys.newLine,
    };
    const message = pretty
        ? typescript_1.default.formatDiagnosticsWithColorAndContext(diagnostics, formatHost)
        : typescript_1.default.formatDiagnostics(diagnostics, formatHost);
    console.warn(message);
}
exports.logDiagnostics = logDiagnostics;
/**
 * @internal
 */
function grey(text) {
    return formatColor(text, EscapeSequence.Grey);
}
exports.grey = grey;
/**
 * @internal
 */
function red(text) {
    return formatColor(text, EscapeSequence.Red);
}
exports.red = red;
/**
 * @internal
 */
function green(text) {
    return formatColor(text, EscapeSequence.Green);
}
exports.green = green;
/**
 * @internal
 */
function yellow(text) {
    return formatColor(text, EscapeSequence.Yellow);
}
exports.yellow = yellow;
/**
 * @internal
 */
function blue(text) {
    return formatColor(text, EscapeSequence.Blue);
}
exports.blue = blue;
/**
 * @internal
 */
function magenta(text) {
    return formatColor(text, EscapeSequence.Magenta);
}
exports.magenta = magenta;
/**
 * @internal
 */
function cyan(text) {
    return formatColor(text, EscapeSequence.Cyan);
}
exports.cyan = cyan;
/**
 * Apply foreground color to text.
 * @internal
 */
function formatColor(text, color) {
    return color + text + EscapeSequence.Reset;
}
/**
 * Foreground color escape sequences.
 * Taken from https://github.com/microsoft/TypeScript/blob/v3.5.3/src/compiler/program.ts#L368
 */
var EscapeSequence;
(function (EscapeSequence) {
    EscapeSequence["Grey"] = "\u001B[90m";
    EscapeSequence["Red"] = "\u001B[91m";
    EscapeSequence["Green"] = "\u001B[92m";
    EscapeSequence["Yellow"] = "\u001B[93m";
    EscapeSequence["Blue"] = "\u001B[94m";
    EscapeSequence["Magenta"] = "\u001B[95m";
    EscapeSequence["Cyan"] = "\u001B[96m";
    EscapeSequence["Reset"] = "\u001B[0m";
})(EscapeSequence || (EscapeSequence = {}));
